package authentication;

import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContext;
import javax.servlet.ServletContextListener;
import java.sql.SQLException;
 
/**
 * Instance tdy bude naslouchat udlostem, kter mn stav v ivotnm cyklu JSP aplikace (instance tdy <code>ServletContext</code>.
 */
public class ApplicationListener implements ServletContextListener
{

/**
 * Vytvo instanci
 */
public ApplicationListener()
{
	super();
} 
/**
 * Metoda je zavolna v okamiku, kdy aplikace ukonuje svoji innost.
 * @param sce ServletContextEvent je udlost informujc o ukonen aplikace.
 */
public void contextDestroyed(ServletContextEvent sce)
{
	ServletContext application = sce.getServletContext();
	UserManager manager = (UserManager) application.getAttribute(Constants.USERMANAGER);
	try 
	{
	 if (manager != null)
	 {
	 	application.removeAttribute(Constants.USERMANAGER);
		manager.closeConnection();
	 }
	}
	catch (SQLException e)
	{
	}
} 
/**
 * Metoda je zavolna v okamiku, kdy aplikace zahajuje svoji innost. K hlavn innosti 
 * pat inicilizace instance tdy <code>UserManager</code>.
 * @param sce ServletContextEvent je udlost informujc o ukonen aplikace.
 */
public void contextInitialized(ServletContextEvent sce)
 {
  ServletContext application = sce.getServletContext();
  UserManager manager = new UserManager();
  manager.setConnectionName(application.getInitParameter("connectionName"));
  manager.setConnectionPassword(application.getInitParameter("connectionPassword"));
  manager.setConnectionURL(application.getInitParameter("connectionURL"));
  manager.setDigest(application.getInitParameter("digest"));
  manager.setDriverName(application.getInitParameter("driverName"));
  manager.setRoleNameCol(application.getInitParameter("roleNameCol"));
  manager.setUserCredCol(application.getInitParameter("userCredCol"));
  manager.setUserNameCol(application.getInitParameter("userNameCol"));
  manager.setUserRoleTable(application.getInitParameter("userRoleTable"));
  manager.setUserTable(application.getInitParameter("userTable"));
  try 
  {
   manager.openConnection();
   application.setAttribute(Constants.USERMANAGER, manager);
   try
   {
   	application.setAttribute(Constants.LOGINFORM, "http:/" + application.getResource("/").getPath() + application.getInitParameter("loginForm"));
   	application.setAttribute(Constants.ERRORPAGE, "http:/" + application.getResource("/").getPath() + application.getInitParameter("loginError"));
   }
   catch (java.net.MalformedURLException e)
   {}
  }
  catch (SQLException e)
  {
   application.log("Nelze inicializovat managera uivatel. Autentifikace nebude fungovat!", e);
  }
  catch (ClassNotFoundException e)
  {
   application.log("Problm s ovladaem pro databzi. Autentifikace nebude fungovat!", e);
  }
 }    
}
