package authentication;

import java.io.IOException;
import java.security.Principal;
import javax.servlet.*;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.util.Set;
import java.util.HashSet;
import java.util.Enumeration;
import java.util.Iterator;

/**
 * Filtr provdjc autentifikaci. Filtr zjist, zda uivatel je asociovn s jednou z rol,
 * kter me propoutt. V ppad, e uivatel nepat do dn z rol, vrt filtr klientov HTTP 
 * chybov kd 403.
 */
public final class AuthenticationFilter implements Filter 
{
/** Mnoina rol, kter filtr propout. */
Set roles;

/**
 * Vytvo instanci
 */
public AuthenticationFilter()
{
 super();
 roles = null;
}

/**
 * Metoda, kter bude zavolna v ppad, e je fitr likvidovn.
 */
public void destroy() 
{
}
/**
 * Metoda zajiujc filtraci HTTP poadavk. Je-li uivatel, kter vyslal poadavek v roli, 
 * kter m filtr nastaven jako propoutc, ped filtr poadavek dle. V opanm ppad vrt klientov 
 * HTTP  chybovou hlku s slem 403.
 * @param request ServletRequest je pchoz HTTP poadavek.
 * @param response ServletResponse je odchoz odpov na poadavek.
 * @param chain FilterChain je etzec dalch filtr.
 */
public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException 
{
	String role;
	if (roles == null) 
	{ // Filtr j njak patn inicializovn
		((HttpServletResponse) response).sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
		return;
	}
	HttpSession session = ((HttpServletRequest) request).getSession();
	ServletContext application = session.getServletContext();
	MyPrincipal principal = (MyPrincipal) session.getAttribute(Constants.USER);
	if (principal != null) 
	{
		for(Iterator e  = principal.getRoles().iterator(); e.hasNext();)
		{ 
			role = (String) e.next();
			if (roles.contains(role))
			{
				chain.doFilter(request, response);
				return;
			}
		}
		((HttpServletResponse) response).sendError(HttpServletResponse.SC_FORBIDDEN);
		return;
	}
	/* Zapu si URL, na kter se uivatel chce pesunout */
	session.setAttribute(Constants.REDIRECT, ((HttpServletRequest)request).getRequestURL());
	/* Pesmruji klienta na pihlaovac formul*/
	((HttpServletResponse) response).sendRedirect((String)application.getAttribute(authentication.Constants.LOGINFORM));
}
/**
 * Metoda zavolna pi inicializaci filtru. Nastav role, kter me filtr propoutt. 
 * Role jsou nakonfigurovny ve web.xml.
 * @param config FilterConfig je objekt s informacemi o konfiguraci.
 */
public void init(FilterConfig filterConfig) throws ServletException 
{
	roles = new HashSet();
	for(Enumeration e = filterConfig.getInitParameterNames(); e.hasMoreElements();)
	{
		String roleName = (String) e.nextElement(), role;
		if (roleName.startsWith("role"))
		{
			role = filterConfig.getInitParameter(roleName);
			roles.add(role);
		}
	}
}
}
